@@ -47,7 +47,7 @@ def list(production_name):
     if production_name:
         # Check if production exists
         check_production(production_name)
-        click.echo(f"The available productions for {production_name} are: ")
+        click.echo(f"The available jobs for {production_name} are: ")
 
         # Get rendered yaml and find all the production names
         with open(os.path.join(production_name, "info.yaml"), "rt") as fp:
